from pathlib import Path
from gslcomp.data_loading import get_input_filenames
from gslcomp.config import ConfigParser
from gslcomp.utils import h5load


def main(conf):
    # main
    print("assert run_main.sh was successful")
    n_grid_points = len(get_input_filenames(conf.input_dir))
    n_hourly_files = len(list(Path(conf.output_dir / "hourly_time_series").glob("gtsm_station*.nc")))
    n_monthly_files = len(list(Path(conf.output_dir / "monthly_time_series").glob("gtsm_station*.nc")))
    n_parameter_files = len(list(Path(conf.output_dir / "parameters").glob("gtsm_station*.nc")))

    print(f"created {n_hourly_files : >6} / {n_grid_points} hourly files")
    print(f"created {n_monthly_files : >6} / {n_grid_points} monthly files")
    print(f"created {n_parameter_files : >6} / {n_grid_points} parameter files")

    # tide gauge comparison
    print("assert that run_tide_gauge_comparison.sh was successful")
    gesla_2, _ = h5load(conf.preprocessed_input / "gesla2_lat_lon.h5")
    n_tide_gauge_stations = len(gesla_2)
    n_single_validation_files = len(list(Path(conf.output_dir / "validation" / "single_files").glob("*.h5")))
    
    print(f"created {n_single_validation_files : >4} / {n_tide_gauge_stations} single validation files")

    # merge validation files
    print(f"assert that run_merge_validation_files.sh was successful")
    
    validation_file = conf.output_dir / "validation" / "validation_measures.h5"
    if validation_file.is_file():
        validation_measures, _ = h5load(validation_file)
        print(f"created a merged validation file for {len(validation_measures) : >4} / {n_tide_gauge_stations} tide gauge locations")
    else:
        print("there is no merged validation file")

if __name__ == "__main__":
    main(ConfigParser().parse())
