import xarray as xr
from gslcomp.config import ConfigParser


def main(conf):
    val_ds_gesla = xr.load_dataset(conf.output_dir / "val_ds_extremes.nc")
    extremes = val_ds_gesla[["w_hour", "hcc"]].sel(time=slice("2011", "2015"))
    extremes_full = extremes.where(
        extremes.w_hour.count(dim="time") == len(extremes.time), drop=True
    )
    extremes_full = extremes_full.rename(
        {"w_hour": "gesla3_water_level_hourly", "hcc": "hcc_water_level_hourly"}
    )
    extremes_full["gesla3_water_level_hourly"].attrs[
        "long_name"
    ] = "Hourly relative water level from the GESLA3 database"
    extremes_full["hcc_water_level_hourly"].attrs[
        "long_name"
    ] = " Hourly relative water level from the HCC dataset"
    f_name = "hcc_gesla3_water_level_hourly_2011_2015.nc"
    extremes_full.to_netcdf(conf.output_dir / f_name)
    print(f"stored {f_name}")


if __name__ == "__main__":
    main(conf=ConfigParser().parse())
