from pathlib import Path

import numpy as np
import xarray as xr
from gslcomp.postprocessing.harmonics_fit import *


def get_pred_tides(val_nc, conf, index):
    tg = val_nc.isel(station_name=index)
    observed_tides = tg.to_series()
    harmonics = fit_harmonics(HARMONICS_START_DATE, HARMONICS_FREQ_D, observed_tides)
    # harmonics gleich lassen und dann aus harmonics letzte zwei zeilen löschen
    tide_fun = harmonics_fun(harmonics[:-2])
    times_d = (observed_tides.index.values - HARMONICS_START_DATE) / np.timedelta64(
        1, "D"
    )
    predicted_tides = pd.Series(tide_fun(times_d), index=observed_tides.index)
    pred_tides_ds = xr.Dataset(
        data_vars={
            "pred_tides": xr.DataArray(
                dims=["time", "station_name"],
                data=np.c_[predicted_tides],
                attrs={
                    "long_name": "Tides predicted from a harmonic fit on observations",
                    "unit": "mm",
                },
            )
        },
        coords=val_nc.isel(station_name=[index]).coords,
    )
    odir = conf.output_dir / "predicted_tides"
    odir.mkdir(parents=True, exist_ok=True)
    station_name = tg.station_name.item()
    if type(station_name) == bytes:
        station_name = station_name.decode("utf-8")
    pred_tides_ds.to_netcdf(odir / f"{station_name}.nc")
    return pred_tides_ds
