"""
Create a single netcdf file containing monthly data for all coDEC grid points
"""

from gslcomp.config import ConfigParser
import xarray as xr
from pathlib import Path

def main(conf):
    files = [f for f in (Path(conf.output_dir) / "monthly_time_series").glob("*.nc")]
    datasets = [xr.open_dataset(f) for f in files]
    global_monthly = xr.concat(datasets, "station_name") 
    global_monthly.to_netcdf(
        conf.output_dir / "monthly_global.nc", format="NETCDF4_CLASSIC"
    )

    global_annual = global_monthly.resample(time="1a").mean()

    global_annual.to_netcdf(
        conf.output_dir / "annual_global.nc", format="NETCDF4_CLASSIC"
    )

if __name__ == "__main__":
    parsed_conf = ConfigParser().parse()
    main(conf=parsed_conf)
