"""combine parameter files into single file"""
import xarray as xr
from gslcomp.config import ConfigParser


def main(conf):
    """combine parameter files"""
    # Get the list of all .nc files
    files = list((conf.output_dir / "predicted_tides").glob("*.nc"))

    # Load each dataset immediately into memory and append to a list
    datasets = [xr.load_dataset(file) for file in files]

    # Concatenate datasets along the "station_name" dimension
    parameters_all_stations = xr.concat(datasets, dim="station_name")

    o_dir = conf.output_dir / "predicted_tides.nc"
    parameters_all_stations.to_netcdf(o_dir)
    print(f"saved merged predicted tides to {o_dir}")


if __name__ == "__main__":
    parsed_conf = ConfigParser().parse()
    main(parsed_conf)
