import pdb
from pathlib import Path

import xarray as xr
from gslcomp.config import ConfigParser


def main(conf):
    # Loop through all grid point files
    hourly_data_dir = conf.output_dir / "hourly_time_series"
    processed_output = conf.output_dir / "hourly_time_series_annual_split"
    processed_output.mkdir(exist_ok=True, parents=True)

    for file in hourly_data_dir.iterdir():
        ds = xr.open_dataset(file)
        if (
            processed_output / f"2015" / f"counterfactual_2015_{file.stem}.nc"
        ).is_file():
            print(f"skipping file exsting {file}")
            continue

        # Loop through years
        for year in range(1979, 2016):
            # Extract data for the specific year
            (processed_output / f"{year}").mkdir(exist_ok=True)
            yearly_data = ds.sel(time=slice(f"{year}-01-01", f"{year}-12-31"))
            # pdb.set_trace()

            # Process for "factual" file
            factual_data = yearly_data[
                [
                    "hcc_relative",
                    "hcc_absolute",
                    "is_dry",
                    "time",
                    "lat",
                    "lon",
                    "station_name",
                ]
            ]
            factual_data.is_dry.encoding = {"_FillValue": 0, "dtype": "int8"}
            factual_data = factual_data.rename(
                {"hcc_relative": "hcc", "hcc_absolute": "hcc_geocentric"}
            )

            # Process for "counterfactual" file
            counterfactual_data = yearly_data[
                [
                    "hcc_relative_cfact",
                    "hcc_absolute_cfact",
                    "is_dry",
                    "time",
                    "lat",
                    "lon",
                    "station_name",
                ]
            ]
            counterfactual_data.is_dry.encoding = {"_FillValue": 0, "dtype": "int8"}
            counterfactual_data = counterfactual_data.rename(
                {
                    "hcc_relative_cfact": "hcc_cfact",
                    "hcc_absolute_cfact": "hcc_geocentric_cfact",
                }
            )

            output_file_factual = (
                processed_output / f"{year}" / f"factual_{year}_{file.stem}.nc"
            )
            output_file_counterfactual = (
                processed_output / f"{year}" / f"counterfactual_{year}_{file.stem}.nc"
            )

            factual_data.to_netcdf(output_file_factual)

            counterfactual_data.to_netcdf(output_file_counterfactual)

        ds.close()


if __name__ == "__main__":
    main(conf=ConfigParser().parse())
