"""
creates an index file for all gtsm locations containing the filenames and a flag "coastal"
"""
import pandas as pd
from gslcomp.utils import h5store
from gslcomp.config import ConfigParser, save_args


def create_gtsm_index(conf):
    """
    creates an index file for all gtsm locations containing the filenames and a flag "coastal" which
    indicates whether this gtsm location is part of the coastal subset
    Parameters
    ----------
    conf: argparse.Namespace
        experiment specific configurations

    Returns
    -------
    gtsm_station_ids: pd.DataFrame
        one row for every gtsm location with lat, lon, filename and coastal
    """
    gtsm_station_ids = pd.read_csv(conf.input_dir / "03_ERA5_id_lon_lat_bedlev.csv")
    gtsm_station_ids.loc[:, "filename"] = gtsm_station_ids.apply(
        lambda row: f'gtsm_station{int(row["id"]):05}', axis=1
    )
    gtsm_station_ids["coastal"] = gtsm_station_ids.apply(
        lambda row: (
            conf.input_dir / "gtsm_tide_surge_slr" / f"{row['filename']}.nc"
        ).is_file(),
        axis=1,
    )
    h5store(conf.preprocessed_input / "gtsm_index.h5", gtsm_station_ids)
    return gtsm_station_ids


if __name__ == "__main__":
    parsed_conf = ConfigParser().parse()
    save_args(vars(parsed_conf), parsed_conf.output_dir / "args.txt")
    create_gtsm_index(conf=parsed_conf)
