"""
preprocessing the slr data from Dewi le Bars using cdo
"""
import subprocess
from pathlib import Path
from gslcomp.config import ConfigParser, save_args


def main(conf):
    """
    preprocessing slr data
    Parameters
    ----------
    conf: argparse.Namespace
        experiment specific configurations

    Returns
    -------
    saves a netcdf file containing yearly sea level on a global grid, where masked areas are extrapolated with distance
    weighted average
    """
    fix_time_unit = "-settaxis,1950-01-01-,00:00:00,1year"
    selvar = "-selvar,TotalRelativeSeaLevel"
    infile = conf.input_dir / Path(
        "TotalSeaLevel_MapsSROCC_rcp85_Perc50_zero1986to2005.nc"
    )
    outfile = conf.preprocessed_input / Path("totalSeaLevel_extrapolated_dis.nc")
    cmd = f"cdo setmisstodis {fix_time_unit} {selvar} {infile} {outfile}"

    subprocess.check_call(cmd, shell=True)


if __name__ == "__main__":
    config = ConfigParser().parse()
    save_args(vars(config), config.output_dir / "args.txt")
    main(config)
