import xarray as xr

from gslcomp.config import ConfigParser, logging_setup
from gslcomp.postprocessing.get_pred_tides import get_pred_tides
from gslcomp.utils import (get_available_slurm_tasks, run_parallelized,
                           select_stations)


def main(conf):
    print(f"Starting {conf.name}")
    n_tasks, task_id = get_available_slurm_tasks()
    logger = logging_setup(conf.output_dir, conf.overwrite)
    with xr.open_dataset(conf.output_dir / "val_ds_extremes.nc") as ds:
        val_nc = ds["w_hour"]

    errors = run_parallelized(
        worker_id=task_id,
        n_workers=n_tasks,
        n_jobs=len(val_nc.station_name),
        logger=logger,
        func=get_pred_tides,
        timeout=conf.timeout,
        kwargs={"val_nc": val_nc, "conf": conf,},
    )
    return errors


if __name__ == "__main__":
    parsed_conf = ConfigParser().parse()
    main(conf=parsed_conf)
